#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_MAKE_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_MAKE_HPP_INCLUDED

#include <boost/simd/memory/include/functions/make.hpp>

#endif
